@@ -9,6 +9,7 @@ import pkg_resources
 import re
 import transformers.utils.logging as tf_logging
 import torch
+from pydoc import locate
 from transformers import (AutoModelForTokenClassification,
                           AutoModelForSequenceClassification,
                           TFAutoModelForTokenClassification,
@@ -17,6 +18,65 @@ from transformers import (AutoModelForTokenClassification,
                           FlaxAutoModelForSequenceClassification,
                           Trainer)
 
+
+def get_all_datasets() -> list:
+    '''Load a list of all datasets.
+
+    Returns:
+        list of tuples:
+            First entry in each tuple is the short name of the dataset, second
+            entry the long name, third entry the benchmark class and fourth
+            entry the loading function.
+    '''
+    return [
+        ('dane', 'DaNE with MISC tags',
+            locate('scandeval.benchmarks.DaneBenchmark'),
+            locate('scandeval.datasets.load_dane')),
+        ('dane-no-misc', 'DaNE without MISC tags',
+            locate('scandeval.benchmarks.DaneNoMiscBenchmark'),
+            locate('scandeval.datasets.load_dane_no_misc')),
+        ('ddt-pos', 'the POS part of DDT',
+            locate('scandeval.benchmarks.DdtPosBenchmark'),
+            locate('scandeval.datasets.load_ddt_pos')),
+        ('ddt-dep', 'the DEP part of DDT',
+            locate('scandeval.benchmarks.DdtDepBenchmark'),
+            locate('scandeval.datasets.load_ddt_dep')),
+        ('angry-tweets', 'AngryTweets',
+            locate('scandeval.benchmarks.AngryTweetsBenchmark'),
+            locate('scandeval.datasets.load_angry_tweets')),
+        ('twitter-sent', 'TwitterSent',
+            locate('scandeval.benchmarks.TwitterSentBenchmark'),
+            locate('scandeval.datasets.load_twitter_sent')),
+        ('twitter-subj', 'TwitterSubj',
+            locate('scandeval.benchmarks.TwitterSubjBenchmark'),
+            locate('scandeval.datasets.load_twitter_subj')),
+        ('europarl-sent', 'EuroparlSent',
+            locate('scandeval.benchmarks.EuroparlSentBenchmark'),
+            locate('scandeval.datasets.load_europarl_sent')),
+        ('europarl-subj', 'EuroparlSubj',
+            locate('scandeval.benchmarks.EuroparlSubjBenchmark'),
+            locate('scandeval.datasets.load_europarl_subj')),
+        ('dkhate', 'DKHate',
+            locate('scandeval.benchmarks.DkHateBenchmark'),
+            locate('scandeval.datasets.load_dkhate')),
+        ('lcc', 'LCC',
+            locate('scandeval.benchmarks.LccBenchmark'),
+            locate('scandeval.datasets.load_lcc')),
+        ('norec', 'NoReC',
+            locate('scandeval.benchmarks.NoReCBenchmark'),
+            locate('scandeval.datasets.load_norec')),
+        ('nordial', 'NorDial',
+            locate('scandeval.benchmarks.NorDialBenchmark'),
+            locate('scandeval.datasets.load_nordial')),
+        ('norne-nb', 'the Bokmål part of NorNE',
+            locate('scandeval.benchmarks.NorneNBBenchmark'),
+            locate('scandeval.datasets.load_norne_nb')),
+        ('norne-nn', 'the Nynorsk part of NorNE',
+            locate('scandeval.benchmarks.NorneNNBenchmark'),
+            locate('scandeval.datasets.load_norne_nn'))
+    ]
+
+
 PT_CLS = {'token-classification': AutoModelForTokenClassification,
           'text-classification': AutoModelForSequenceClassification}
 TF_CLS = {'token-classification': TFAutoModelForTokenClassification,
